@@ -1,9 +1,9 @@
 /**
- * Copyright (c) 2004 Michael Terry
+ * Copyright (c) 2004-2007 Michael Terry
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
@@ -112,7 +112,7 @@ void
 xpad_pad_group_add (XpadPadGroup *group, GtkWidget *pad)
 {
 	g_object_ref(pad);
-	gtk_object_sink(GTK_OBJECT(pad));
+	g_object_ref_sink(GTK_OBJECT(pad));
 	
 	group->priv->pads = g_slist_append (group->priv->pads, XPAD_PAD (pad));
 	g_signal_connect_swapped (pad, "destroy", G_CALLBACK (xpad_pad_group_remove), group);
@@ -141,3 +141,37 @@ xpad_pad_group_destroy_pads (XpadPadGroup *group)
 	g_slist_free (group->priv->pads);
 	group->priv->pads = NULL;
 }
+
+
+gint
+xpad_pad_group_num_visible_pads (XpadPadGroup *group)
+{
+	gint num = 0;
+	if (group)
+	{
+		GSList *i;
+		for (i = group->priv->pads; i; i = i->next)
+		{
+			if (GTK_WIDGET_VISIBLE(GTK_WIDGET(i->data)))
+				num ++;
+		}
+	}
+	return num;
+}
+
+
+void
+xpad_pad_group_close_all (XpadPadGroup *group)
+{
+	if (group)
+		g_slist_foreach (group->priv->pads, (GFunc) xpad_pad_close, NULL);
+}
+
+
+void
+xpad_pad_group_show_all (XpadPadGroup *group)
+{
+	if (group)
+		g_slist_foreach (group->priv->pads, (GFunc) gtk_widget_show, NULL);
+}
+
